yolkbot may be ported to Python in the future. who knows?

join our discord for updates: https://discord.gg/VUVRmmCXzN

---

IF YOU WANT TO CLAIM THIS PACKAGE IS PARKED, READ THE FOLLOWING:

I am VillainsRule, the certified owner of https://github.com/yolkorg and https://yolkbot.xyz. I own an established project named yolkbot at https://github.com/yolkorg/yolkbot. There is risk that users may take this package and attempt to claim that it is a Python port of yolkbot; it is not. If you have concerns about parking, please contact me at hello@villainsrule.xyz.